/**
 * Implementation of the openIframe Ajax command.
 *
 * This command uses the default openDialog command to initialize a dialog. It
 * then attaches event listeners to the iframe and window to handle closing and
 * resizing the dialog.
 */
(function ($, Drupal) {
  Drupal.AjaxCommands.prototype.openIframe = function (ajax, response, status) {
    Drupal.AjaxCommands.prototype.openDialog(ajax, response, status)
    this.openIframe.initialResize(ajax.wrapper)
    this.openIframe.initMessageListener()
  };

  /**
   * Listens for the initial load event of the iframe and sets the height of
   * the modal to match the height of the iframe content window.
   */
  Drupal.AjaxCommands.prototype.openIframe.initialResize = function (wrapper) {
    var dialog = $('#' + wrapper)
    var dialogHeight = window.innerHeight - 180
    var dialogWidth = window.innerWidth - 180
    dialog.dialog('option', 'height', dialogHeight)
    dialog.dialog('option', 'width', dialogWidth)
  }

  /**
   * Attaches a message event listener to the window.
   *
   * The loaded document in the iframe will redirect to a special route, which
   * uses postMessage to send a message to the parent. This means we can
   * trigger a rebuild of the layout, which in return will close the dialog.
   */
  Drupal.AjaxCommands.prototype.openIframe.initMessageListener = function () {
    if (this._isInitialized) {
      return
    }
    this._isInitialized = true
    window.addEventListener("message", function (e) {
      if (e.data === 'LBIM_REDIRECT') {
        $('#edit-rebuild-layout').trigger('click')
      }
    }, false);
  }
})(jQuery, Drupal);
